==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAthrow.h <==
// class soot.coffi.Instruction_Athrow

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 921cd6a9c7947626 soot_coffi_Instruction__5fAthrow
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAthrow_H_
#define _JC_soot_coffi_Instruction__5fAthrow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAthrow$sub_refs	_jc_soot_coffi_Instruction__5fAthrow$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs	_jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$refs	_jc_soot_coffi_Instruction__5fAthrow$refs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$nonrefs	_jc_soot_coffi_Instruction__5fAthrow$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$object	_jc_soot_coffi_Instruction__5fAthrow$object;

typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vmethods	_jc_soot_coffi_Instruction__5fAthrow$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vtable	_jc_soot_coffi_Instruction__5fAthrow$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vtype	_jc_soot_coffi_Instruction__5fAthrow$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAthrow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *);

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fAthrow$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *, struct _jc_soot_coffi_Instruction$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fAthrow$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAthrow$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *, struct _jc_soot_coffi_Instruction$object *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAthrow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAthrow$vmethods	soot_coffi_Instruction__5fAthrow;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAthrow$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAthrow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAthrow$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAthrow$refs {
    _jc_soot_coffi_Instruction__5fAthrow$sub_refs	soot_coffi_Instruction__5fAthrow;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAthrow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs	soot_coffi_Instruction__5fAthrow;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAthrow$object {
	_jc_soot_coffi_Instruction__5fAthrow$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAthrow$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAthrow$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAthrow$vtype _jc_soot_coffi_Instruction__5fAthrow$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAthrow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAthrow$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAthrow_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAthrow.h <==
// class soot.coffi.Instruction_Athrow

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 921cd6a9c7947626 soot_coffi_Instruction__5fAthrow
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAthrow_H_
#define _JC_soot_coffi_Instruction__5fAthrow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAthrow$sub_refs	_jc_soot_coffi_Instruction__5fAthrow$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs	_jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$refs	_jc_soot_coffi_Instruction__5fAthrow$refs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$nonrefs	_jc_soot_coffi_Instruction__5fAthrow$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAthrow$object	_jc_soot_coffi_Instruction__5fAthrow$object;

typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vmethods	_jc_soot_coffi_Instruction__5fAthrow$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vtable	_jc_soot_coffi_Instruction__5fAthrow$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAthrow$vtype	_jc_soot_coffi_Instruction__5fAthrow$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAthrow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fAthrow$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fAthrow$method_info$branchpoints$0387b0529fae51a0;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAthrow$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fAthrow$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAthrow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAthrow$vmethods	soot_coffi_Instruction__5fAthrow;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAthrow$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAthrow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAthrow$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAthrow$refs {
    _jc_soot_coffi_Instruction__5fAthrow$sub_refs	soot_coffi_Instruction__5fAthrow;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAthrow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAthrow$sub_nonrefs	soot_coffi_Instruction__5fAthrow;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAthrow$object {
	_jc_soot_coffi_Instruction__5fAthrow$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAthrow$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAthrow$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAthrow$vtype _jc_soot_coffi_Instruction__5fAthrow$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAthrow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAthrow$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAthrow_H_ */
